/***************************************************************************
                          libkeyer part of Aldo
                          ---------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : rdmartin@infinito.it
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include "keyer.h"

using namespace libkeyer;

// Default speed is 8 word per minute in count per minute is 400 cpm

Keyer::Keyer()
:m_intrach(1), m_interch(3), m_interword(7)
{
    double tmp = 8000 * 60/400; // 8 wpm == 400 cpm
    m_count = int(tmp);
}

Keyer::Keyer(unsigned int speed)
:m_intrach(1), m_interch(3), m_interword(7)
{
    double tmp = 8000 * 60/speed;
    m_count = int(tmp);
}

Keyer::Keyer(unsigned int intrach, unsigned int interch, unsigned int interwd)
:m_intrach(intrach), m_interch(interch), m_interword(interwd)
{
    double tmp = 8000 * 60/400; // 8 wpm == 400 cpm
    m_count = int(tmp);
}


Keyer::Keyer(unsigned int speed, unsigned int intrach, unsigned int interch, unsigned int interwd)
:m_intrach(intrach), m_interch(interch), m_interword(interwd)
{
    double tmp = 8000 * 60/speed;
    m_count = int(tmp);
}

Keyer& Keyer::operator<<(unsigned int n)
{
    int duration = m_count * n;

    libaudiostream::SineWave tone(duration, 1, 900.0, 0.0);
    libaudiostream::Pause pause(m_count * m_intrach);

    m_audio<<tone<<pause;
    
    return *this;
}   

void Keyer::char_pause()
{
    int duration = m_count * m_interch;

    libaudiostream::Pause pause(duration);

    m_audio<<pause;
}


void Keyer::string_pause()
{
    int duration = m_count * m_interword;

    libaudiostream::Pause pause(duration);

    m_audio<<pause;
}


void Keyer::pause(unsigned int sec)
{
    int duration = 8000*sec;

    libaudiostream::Pause pause(duration);

    m_audio<<pause;
}
