/***************************************************************************
                           Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : rdmartin@infinito.it
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include "resources.h"

#include "dialog.h"
#include "exercise.h"
#include "keyer.h"
#include "datafile.h"

#include <iostream>
#include <fstream>

using namespace std;

void OnCheck();

void OnQuickStart()
{
    unsigned int speed;
    unsigned int begin_pause; // pause of 2 sec
    unsigned int ch_pause;
    unsigned int str_pause;
    unsigned int str_length;
    unsigned int num_strings;
    libmorse::Skill skill;

    // read config from ~/.aldorc
    try
    {
	string fileconf_name(getenv("HOME"));
	fileconf_name += "/.aldorc";

	libdatafile::Datafile fileconf(fileconf_name, libdatafile::Read);
	
	libdatafile::sec_it quick_sec = fileconf.section("Quickstart");
	libdatafile::sec_it main_sec = fileconf.section("Main");

	speed = quick_sec->option("Speed")->get();

	num_strings = quick_sec->option("StringsNumber")->get();

	skill = libmorse::inttoskill(quick_sec->option("Skill")->get());

	ch_pause = main_sec->option("CharPause")->get();
	
	str_pause = main_sec->option("StringPause")->get();

	str_length = main_sec->option("StringLength")->get();
	
	begin_pause = main_sec->option("DefaultBeginPause")->get();
    }
    catch(libdatafile::Not_datafile_format e)
    {
	cerr<<errmsg_noformat<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Over_write_file e)
    {
	cerr<<errmsg_overwrite<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Option_not_found e)
    {
	cerr<<errmsg_nooption<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Section_not_found e)
    {
	cerr<<errmsg_nosection<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::File_not_opened e)
    {
	cerr<<errmsg_noopenfile<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::File_not_exist e)
    {
	cerr<<errmsg_nofile<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
      
    libkeyer::Keyer current_keyer(speed,1,ch_pause, str_pause);
    
    cout<<msg_speed<<speed<<" cpm"<<endl;
    cout<<msg_strlen<<str_length<<endl;
    cout<<msg_strnum<<num_strings<<endl;
    
    std::string skill_list[]={dlg_skill_choice1, dlg_skill_choice2, dlg_skill_choice3, dlg_skill_choice4, dlg_skill_choice5,
			      dlg_skill_choice6};

    cout<<msg_skill<<skill_list[skilltoint(skill)]<<endl;
    cout<<msg_start<<endl;
  
    current_keyer.pause(2*begin_pause);
    
    libmorse::Exercise current_exercise(num_strings, skill, str_length);
    current_keyer<<current_exercise;

    current_keyer.pause(begin_pause);

    ofstream file("Strings.txt");
    file<<current_exercise;

    OnCheck(); // Show strings just listened
}
