/***************************************************************************
                           Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : rdmartin@infinito.it
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include "resources.h"

#include "dialog.h"
#include "exercise.h"
#include "keyer.h"
#include "datafile.h"

#include <iostream>
#include <fstream>
#include <cstdlib>

using namespace std;

void OnCheck();

void OnNewSpeed()
{
    unsigned int begin_pause;
    unsigned int ch_pause;
    unsigned int str_pause;
    unsigned int str_length;

    //read config from datafile
    try
    {
	string fileconf_name(getenv("HOME"));
	fileconf_name += "/.aldorc";

	libdatafile::Datafile fileconf(fileconf_name, libdatafile::Read);
	
	libdatafile::sec_it main_sec = fileconf.section("Main");

	ch_pause = main_sec->option("CharPause")->get();
	str_pause = main_sec->option("StringPause")->get();
	str_length = main_sec->option("StringLength")->get();
	begin_pause = main_sec->option("DefaultBeginPause")->get();
    }
    catch(libdatafile::Not_datafile_format e)
    {
	cerr<<errmsg_noformat<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Over_write_file e)
    {
	cerr<<errmsg_overwrite<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Option_not_found e)
    {
	cerr<<errmsg_nooption<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::Section_not_found e)
    {
	cerr<<errmsg_nosection<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::File_not_opened e)
    {
	cerr<<errmsg_noopenfile<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
    catch(libdatafile::File_not_exist e)
    {
	cerr<<errmsg_nofile<<endl;
	cerr<<errmsg_conf<<endl;
	return;
    }
      
    Dialog<int> ask_speed(dlg_speed_title, main_menu_prompt);
    ask_speed.add_choice(dlg_speed_choice1,400);
    ask_speed.add_choice(dlg_speed_choice2,500);
    ask_speed.add_choice(dlg_speed_choice3,600);
    ask_speed.add_choice(dlg_speed_choice4,700);
    ask_speed.add_choice(dlg_speed_choice5,1);
    ask_speed.add_choice(dlg_speed_choice6,2);

    int speed = ask_speed.show(); // return speed in cpm

    if(speed == 1)
    {
	cout<<insert_cpm;
	cin>>speed;
	speed = speed*10;
    }

    if(speed == 2)
    {
	cout<<insert_wpm;
	int tmp;
	cin >> tmp; // read speed in wpm
	speed = 50 * tmp; // conversion from wpm to cpm 
    }

    libkeyer::Keyer current_keyer(speed, 1, ch_pause, str_pause);

    unsigned int num_strings;
    cout<<ask_num_of_strings;
    cin>>num_strings;

    Dialog<libmorse::Skill> ask_skill(dlg_skill_title, main_menu_prompt);
    ask_skill.add_choice(dlg_skill_choice1,libmorse::beginner);
    ask_skill.add_choice(dlg_skill_choice2,libmorse::lo_medium);
    ask_skill.add_choice(dlg_skill_choice3,libmorse::hi_medium);
    ask_skill.add_choice(dlg_skill_choice4,libmorse::all_letters);
    ask_skill.add_choice(dlg_skill_choice5,libmorse::numbers);
    ask_skill.add_choice(dlg_skill_choice6,libmorse::all);

    libmorse::Skill skill = ask_skill.show();

    cout<<msg_start<<endl;
    current_keyer.pause(begin_pause);

    libmorse::Exercise current_exercise(num_strings, skill, str_length);
    current_keyer<<current_exercise;
    current_keyer.pause(begin_pause);

    ofstream file("Strings.txt");
    file<<current_exercise;
    
    OnCheck(); // Show strings just listened
}
